@@ -20,7 +20,7 @@
 #ifndef __HOMEBANK_DEFOPERATION_H__
 #define __HOMEBANK_DEFOPERATION_H__
 
-GtkWidget *create_defoperation_window (Operation *ope, gint type, gint accnum);
+GtkWidget *create_defoperation_window (GtkWindow *parent, Operation *ope, gint type, gint accnum);
 void defoperation_set_operation(GtkWidget *widget, Operation *ope);
 void defoperation_get			(GtkWidget *widget, gpointer user_data);
 void defoperation_add			(GtkWidget *widget, gpointer user_data);
