@@ -43,13 +43,19 @@
 struct HomeBank *GLOBALS;
 struct Preferences *PREFS;
 
-gchar *homebank_pixmaps_dir = PIXMAPS_DIR;
-gchar *homebank_locale_dir = LOCALE_DIR;;
+
+/* installation paths */
+static gchar *pixmaps_dir  = NULL;
+static gchar *locale_dir   = NULL;
+static gchar *help_dir     = NULL;
+
 
 static struct { 
   gchar *filename;
   gchar *stock_id;
 } stock_icons[] = {
+  { "homebank.svg"            , "hb-stock-homebank" },
+
   { "account.svg"             , "hb-stock-account" },
   { "payee.svg"               , "hb-stock-payee" },
   { "category.svg"            , "hb-stock-category" },
@@ -80,8 +86,8 @@ static struct {
   { "refresh.svg"            , "hb-stock-refresh" },
 
   { "lpi-help.png"           , "hb-lpi-help" },
-  { "lpi-translate.png"      , "hb-lpi-translate" },
-  { "lpi-bug.png"            , "hb-lpi-bug" },
+  { "lpi-translate.svg"      , "hb-lpi-translate" },
+  { "lpi-bug.svg"            , "hb-lpi-bug" },
 
 };
  
@@ -120,6 +126,7 @@ gint result;
 	                                  GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 	                                  GTK_MESSAGE_QUESTION,
 	                                  GTK_BUTTONS_YES_NO,
+	                                  "%s", 
 	                                  title
 	                                  );
 
@@ -129,7 +136,7 @@ gint result;
       msg = g_strdup_vprintf (message_format, args);
       va_end (args);
 
-		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), msg);
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), "%s", msg);
 
       g_free (msg);
     }
@@ -155,6 +162,7 @@ va_list args;
 	                                  GTK_DIALOG_DESTROY_WITH_PARENT,
 	                                  type,
 	                                  GTK_BUTTONS_CLOSE,
+	                                  "%s", 
 	                                  title
 	                                  );
 
@@ -164,7 +172,7 @@ va_list args;
       msg = g_strdup_vprintf (message_format, args);
       va_end (args);
 
-		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), msg);
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), "%s", msg);
 
       g_free (msg);
     }
@@ -173,6 +181,57 @@ va_list args;
 	 gtk_widget_destroy (dialog);
 }
 
+/*
+** 
+*/
+gboolean homebank_chooser_open_qif(GtkWindow *parent, gchar **storage_ptr)
+{
+GtkWidget *chooser;
+GtkFileFilter *filter;
+gboolean retval;
+
+	DB( g_printf("(homebank) chooser open qif\n") );
+
+	chooser = gtk_file_chooser_dialog_new (
+					_("Export as QIF"),
+					GTK_WINDOW(GLOBALS->mainwindow),
+					GTK_FILE_CHOOSER_ACTION_SAVE,
+					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
+					NULL);
+
+	//todo chnage this ?	
+	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER(chooser), PREFS->path_export);
+
+	filter = gtk_file_filter_new ();
+	gtk_file_filter_set_name (filter, _("QIF files"));
+	gtk_file_filter_add_pattern (filter, "*.qif");
+	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER(chooser), filter);
+
+	filter = gtk_file_filter_new ();
+	gtk_file_filter_set_name (filter, _("All files"));
+	gtk_file_filter_add_pattern (filter, "*");
+	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER(chooser), filter);
+
+	retval = FALSE;
+	if (gtk_dialog_run (GTK_DIALOG (chooser)) == GTK_RESPONSE_ACCEPT)
+	{
+    gchar *filename;
+
+	    filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (chooser));
+
+		*storage_ptr = filename;
+
+		retval = TRUE;
+	}
+
+	gtk_widget_destroy (chooser);
+
+	return retval;
+}
+
+
+
 /*
 ** open a file chooser dialog and store filename to GLOBALS if OK
 */
@@ -183,6 +242,7 @@ GtkFileFilter *filter;
 gchar *title;
 gchar *button;
 gboolean retval;
+gchar *path;
 
 	DB( g_printf("(hombank) csvfile chooser %d\n", action) );
 
@@ -190,11 +250,13 @@ gboolean retval;
 	{
 		title = _("Import from CSV");
 		button = GTK_STOCK_OPEN;
+		path = PREFS->path_import;
 	}
 	else
 	{
 		title = _("Export as CSV");
 		button = GTK_STOCK_SAVE;
+		path = PREFS->path_export;
 	}
 
 	chooser = gtk_file_chooser_dialog_new (title,
@@ -204,13 +266,15 @@ gboolean retval;
 					button, GTK_RESPONSE_ACCEPT,
 					NULL);
 
+	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER(chooser), path);
+
 	filter = gtk_file_filter_new ();
 	gtk_file_filter_set_name (filter, _("CSV files"));
 	gtk_file_filter_add_pattern (filter, "*.csv");
 	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER(chooser), filter);
 
 	filter = gtk_file_filter_new ();
-	gtk_file_filter_set_name (filter, _("All"));
+	gtk_file_filter_set_name (filter, _("All files"));
 	gtk_file_filter_add_pattern (filter, "*");
 	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER(chooser), filter);
 
@@ -253,12 +317,12 @@ gboolean retval;
 
 	if( action == GTK_FILE_CHOOSER_ACTION_OPEN )
 	{
-		title = "Open a wallet";
+		title = _("Open homebank file");
 		button = GTK_STOCK_OPEN;
 	}
 	else
 	{
-		title = "Save wallet as";
+		title = _("Save homebank file as");
 		button = GTK_STOCK_SAVE;
 	}
 
@@ -270,12 +334,12 @@ gboolean retval;
 					NULL);
 
 	filter = gtk_file_filter_new ();
-	gtk_file_filter_set_name (filter, "HB Wallet");
+	gtk_file_filter_set_name (filter, _("HomeBank files"));
 	gtk_file_filter_add_pattern (filter, "*.xhb");
 	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER(chooser), filter);
 
 	filter = gtk_file_filter_new ();
-	gtk_file_filter_set_name (filter, _("All"));
+	gtk_file_filter_set_name (filter, _("All files"));
 	gtk_file_filter_add_pattern (filter, "*");
 	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER(chooser), filter);
 
@@ -368,6 +432,8 @@ gboolean retval;
 }
 
 
+
+
 /*
 ** open an alien file chooser dialog and store filename to GLOBALS if OK
 */
@@ -386,7 +452,7 @@ gboolean retval;
 					GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
 					NULL);
 
-	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER(chooser), PREFS->path_wallet);
+	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER(chooser), PREFS->path_import);
 
 	filter = gtk_file_filter_new ();
 	gtk_file_filter_set_name (filter, _("Amiga files"));
@@ -394,7 +460,7 @@ gboolean retval;
 	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER(chooser), filter);
 
 	filter = gtk_file_filter_new ();
-	gtk_file_filter_set_name (filter, _("All"));
+	gtk_file_filter_set_name (filter, _("All files"));
 	gtk_file_filter_add_pattern (filter, "*");
 	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER(chooser), filter);
 
@@ -421,13 +487,13 @@ gboolean retval;
 	return retval;
 }
 
-
 /* = = = = = = = = = = = = = = = = = = = = */
 /* file backup */
 gchar *homebank_get_filename_with_extension(gchar *path, gchar *extension)
 {
 gchar *basename;
 gchar *dirname;
+gchar *filename;
 gchar *newname;
 gchar **str_array;
 
@@ -436,15 +502,35 @@ gchar **str_array;
 
 	str_array = g_strsplit(basename, ".", 0);
 
-	newname = g_strdup_printf("%s/%s.%s", dirname, str_array[0], extension);	
+	filename = g_strdup_printf("%s.%s", str_array[0], extension);	
+
+	newname = g_build_filename(dirname, filename, NULL);
 
 	g_strfreev(str_array);
 	g_free(basename);
 	g_free(dirname);
+	g_free(filename);
 
 	return newname;
 }
 
+gchar *homebank_get_filename_without_extension(gchar *path)
+{
+gchar *basename;
+gchar *newname;
+gchar **str_array;
+
+	basename = g_path_get_basename(path);
+
+	str_array = g_strsplit(basename, ".", 0);
+
+	newname = g_strdup(str_array[0]);	
+
+	g_strfreev(str_array);
+	g_free(basename);
+
+	return newname;
+}
 
 
 
@@ -464,11 +550,14 @@ gchar *dirname;
 	if( !(g_str_has_suffix(basename, ".xhb")))
 	{
 	gchar **str_array;
+	gchar *filename;
 	gchar *newname;
 
 		str_array = g_strsplit(basename, ".", 0);
-		newname = g_strdup_printf("%s/%s.xhb", dirname, str_array[0]);	
+		filename = g_strdup_printf("%s.xhb", str_array[0]);	
 		g_strfreev(str_array);
+		newname = g_build_filename(dirname, filename, NULL);
+		g_free(filename);
 
 		g_free(GLOBALS->filename);
 		GLOBALS->filename = newname;
@@ -487,6 +576,7 @@ void homebank_backup_current_file(gchar *pathname)
 {
 gchar *basename;
 gchar *dirname;
+gchar *filename;
 gchar *newname;
 gchar **str_array;
 int retval;
@@ -497,7 +587,9 @@ int retval;
 	if( g_str_has_suffix(basename, ".xhb") )
 	{
 		str_array = g_strsplit(basename, ".", 0);
-		newname = g_strdup_printf("%s/%s.old", dirname, str_array[0]);	
+		filename = g_strdup_printf("%s.xhb~", str_array[0]);	
+		newname = g_build_filename(dirname, filename, NULL);
+		g_free(filename);
 
 		if( g_file_test(newname, G_FILE_TEST_EXISTS) )
 		{
@@ -528,11 +620,12 @@ int retval;
 static gboolean
 homebank_util_url_show_win32 (const gchar *url)
 {
-	gint retval;
+gint retval;
+
 	/* win32 API call */
 	retval = ShellExecuteA (NULL, "open", url, NULL, NULL, SW_NORMAL);
 	
-	if (code <= 32)
+	if (retval <= 32)
 		return FALSE;
 
 	return TRUE;
@@ -678,13 +771,22 @@ gchar *group, *filename;
 	keyfile = g_key_file_new();
 	if(keyfile)
 	{
-		filename = g_strdup_printf("%s/.homebank/lastopenedfiles", g_get_home_dir ());
+		filename = g_build_filename(g_get_home_dir (), HB_DATA_PATH, "lastopenedfiles", NULL );
+		//filename = g_strdup_printf("%s/.homebank/lastopenedfiles", g_get_home_dir ());
+
+		DB( g_print(" -> filename: %s\n", filename) );
+
 		if(g_key_file_load_from_file (keyfile, filename, G_KEY_FILE_NONE, NULL))
 		{
 			group = "HomeBank";
 
+            DB( g_print(" -> load keyfile ok\n") );
+
 			if(g_key_file_has_key(keyfile, group, "LastOpenedFile", NULL))
 			{
+                DB( g_print(" -> keyfile has key ok\n") );
+
+
 				GLOBALS->filename = g_strdup(g_key_file_get_string  (keyfile, group, "LastOpenedFile", NULL));
 				DB( g_print("lastfile loaded: %s\n", GLOBALS->filename ) );
 				retval = TRUE;
@@ -694,12 +796,15 @@ gchar *group, *filename;
 		g_key_file_free (keyfile);
 	}
 
+	DB( g_print(" -> return: %d\n", retval) );
+
+
 	return retval;
 }
 
 
 /*
-** save lastopenedfiles to homedir/.homebank
+** save lastopenedfiles to homedir/.homebank (HB_DATA_PATH)
 */
 gboolean homebank_lastopenedfiles_save(void)
 {
@@ -723,7 +828,8 @@ guint length;
 
 			//DB( g_print(" keyfile:\n%s\nlen=%d\n", contents, length) );
 
-			filename = g_strdup_printf("%s/.homebank/lastopenedfiles", g_get_home_dir ());
+			//filename = g_strdup_printf("%s/" HB_DATA_PATH "/lastopenedfiles", g_get_home_dir ());
+			filename = g_build_filename(g_get_home_dir (), HB_DATA_PATH, "lastopenedfiles", NULL );
 			g_file_set_contents(filename, contents, length, NULL);
 			g_free(filename);
 
@@ -755,6 +861,7 @@ guint i;
 
 static void load_list_pixbuf(void)
 {
+gchar *filename;
 guint i;
 
 	DB( g_print("\n(homebank) load_list_pixbuf\n") );
@@ -765,12 +872,35 @@ guint i;
     //GLOBALS->lst_pixbuf[LST_PIXBUF_VALID]  = gdk_pixbuf_new_from_file(PIXMAPS_DIR "/lst_vali.png", NULL);
 	//GLOBALS->lst_pixbuf[LST_PIXBUF_AUTO]   = gdk_pixbuf_new_from_file(PIXMAPS_DIR "/lst_auto.svg", NULL);
 
-    GLOBALS->lst_pixbuf[LST_PIXBUF_ADD]     = gdk_pixbuf_new_from_file_at_size(PIXMAPS_DIR "/lst_new.svg", 16, 16, NULL);
-	GLOBALS->lst_pixbuf[LST_PIXBUF_AUTO]    = gdk_pixbuf_new_from_file_at_size(PIXMAPS_DIR "/lst_auto.svg", 16, 16, NULL);
-    GLOBALS->lst_pixbuf[LST_PIXBUF_EDIT]    = gdk_pixbuf_new_from_file_at_size(PIXMAPS_DIR "/lst_edit.svg", 16, 16, NULL);
-    GLOBALS->lst_pixbuf[LST_PIXBUF_REMIND]  = gdk_pixbuf_new_from_file_at_size(PIXMAPS_DIR "/lst_remind.svg", 16, 16, NULL);
-	GLOBALS->lst_pixbuf[LST_PIXBUF_VALID]   = gdk_pixbuf_new_from_file_at_size(PIXMAPS_DIR "/lst_vali.svg", 16, 16, NULL);
-	GLOBALS->lst_pixbuf[LST_PIXBUF_WARNING] = gdk_pixbuf_new_from_file_at_size(PIXMAPS_DIR "/lst_warning.svg", 16, 16, NULL);
+	//todo: rework that
+	filename = g_build_filename(homebank_app_get_pixmaps_dir(), "/lst_new.svg", NULL);
+    GLOBALS->lst_pixbuf[LST_PIXBUF_ADD]     = gdk_pixbuf_new_from_file_at_size(filename, 16, 16, NULL);
+	g_free(filename);
+
+	filename = g_build_filename(homebank_app_get_pixmaps_dir(), "/lst_auto.svg", NULL);
+	GLOBALS->lst_pixbuf[LST_PIXBUF_AUTO]    = gdk_pixbuf_new_from_file_at_size(filename, 16, 16, NULL);
+	g_free(filename);
+
+
+	filename = g_build_filename(homebank_app_get_pixmaps_dir(), "/lst_edit.svg", NULL);
+    GLOBALS->lst_pixbuf[LST_PIXBUF_EDIT]    = gdk_pixbuf_new_from_file_at_size(filename, 16, 16, NULL);
+	g_free(filename);
+
+
+	filename = g_build_filename(homebank_app_get_pixmaps_dir(), "/lst_remind.svg", NULL);
+    GLOBALS->lst_pixbuf[LST_PIXBUF_REMIND]  = gdk_pixbuf_new_from_file_at_size(filename, 16, 16, NULL);
+	g_free(filename);
+
+
+	filename = g_build_filename(homebank_app_get_pixmaps_dir(), "/lst_vali.svg", NULL);
+	GLOBALS->lst_pixbuf[LST_PIXBUF_VALID]   = gdk_pixbuf_new_from_file_at_size(filename, 16, 16, NULL);
+	g_free(filename);
+
+
+	filename = g_build_filename(homebank_app_get_pixmaps_dir(), "/lst_warning.svg", NULL);
+	GLOBALS->lst_pixbuf[LST_PIXBUF_WARNING] = gdk_pixbuf_new_from_file_at_size(filename, 16, 16, NULL);
+	g_free(filename);
+
 
 	GLOBALS->lst_pixbuf_maxwidth = 0;
 	for(i=0;i<NUM_LST_PIXBUF;i++)
@@ -796,19 +926,22 @@ guint i;
 static void homebank_register_stock_icons()
 {
    GtkIconFactory *icon_factory;
-   GtkIconSet *icon_set; 
+   GtkIconSet *icon_set;
    GtkIconSource *icon_source;
    gchar *filename;
    gint i;
 
    icon_factory = gtk_icon_factory_new ();
-   
-   for (i = 0; i < n_stock_icons; i++) 
+
+   for (i = 0; i < n_stock_icons; i++)
     {
       icon_set = gtk_icon_set_new ();
       icon_source = gtk_icon_source_new ();
-      filename = g_build_filename(homebank_pixmaps_dir, stock_icons[i].filename, NULL);
-     gtk_icon_source_set_filename (icon_source, filename);
+
+      //todo: win32
+      filename = g_build_filename(homebank_app_get_pixmaps_dir(), stock_icons[i].filename, NULL);
+
+      gtk_icon_source_set_filename (icon_source, filename);
       gtk_icon_set_add_source (icon_set, icon_source);
       gtk_icon_source_free (icon_source);
       gtk_icon_factory_add (icon_factory, stock_icons[i].stock_id, icon_set);
@@ -816,7 +949,7 @@ static void homebank_register_stock_icons()
        g_free(filename);
    }
 
-   gtk_icon_factory_add_default (icon_factory); 
+   gtk_icon_factory_add_default (icon_factory);
 
    g_object_unref (icon_factory);
 
@@ -826,13 +959,70 @@ void homebank_window_set_icon_from_file(GtkWindow *window, gchar *filename)
 {
 gchar *pathfilename;
 
-	pathfilename = g_build_filename(homebank_pixmaps_dir, filename, NULL);
+	pathfilename = g_build_filename(homebank_app_get_pixmaps_dir(), filename, NULL);
 	gtk_window_set_icon_from_file(GTK_WINDOW (window), pathfilename, NULL);
 	g_free(pathfilename);
 }
 
+
+
+
+const gchar *
+homebank_app_get_pixmaps_dir (void)
+{
+	return pixmaps_dir;
+}
+
+const gchar *
+homebank_app_get_locale_dir (void)
+{
+	return locale_dir;
+}
+
+const gchar *
+homebank_app_get_help_dir (void)
+{
+	return help_dir;
+}
+
+/* build package paths at runtime */
+static void
+build_package_paths (void)
+{
+#ifdef G_OS_WIN32
+	gchar *prefix;
+	
+	prefix = g_win32_get_package_installation_directory (NULL, NULL);
+	pixmaps_dir  = g_build_filename (prefix, "share", PACKAGE, "pixmaps", NULL);
+	locale_dir   = g_build_filename (prefix, "share", "locale", NULL);
+	help_dir     = g_build_filename (prefix, "share", PACKAGE, "help", NULL);
+	g_free (prefix);
+#else
+	pixmaps_dir  = g_strdup (HOMEBANK_PIXMAPSDIR);
+	locale_dir   = g_strdup (HOMEBANK_LOCALEDIR);
+	help_dir     = g_strdup (HOMEBANK_HELPDIR);
+#endif
+
+	DB( g_print("pixmaps_dir: %s\n", pixmaps_dir) );
+	DB( g_print("locale_dir : %s\n", locale_dir) );
+	DB( g_print("help_dir   : %s\n", help_dir) );
+
+}
+
+
+
+
+
+
+
+
+
+
+
+
+
 /*
- * check/create user home directory for .homebank directory
+ * check/create user home directory for .homebank (HB_DATA_PATH) directory
  */
 static void homebank_check_app_dir()
 {
@@ -841,7 +1031,8 @@ gboolean exists;
 
 	DB( g_print("homebank_check_app_dir()\n") );
 
-	homedir = g_strdup_printf("%s/.homebank", g_get_home_dir ());
+	//homedir = g_strdup_printf("%s/" HB_DATA_PATH, g_get_home_dir ());
+	homedir = g_build_filename(g_get_home_dir (), HB_DATA_PATH, NULL );
 	exists = g_file_test(homedir, G_FILE_TEST_IS_DIR);
 	if(!exists)
 		g_mkdir(homedir, 0755);
@@ -871,9 +1062,13 @@ static void homebank_cleanup()
 	/* free our GList */
 	da_operation_destroy(GLOBALS->ope_list);
 	da_archive_destroy(GLOBALS->arc_list);
-	da_category_destroy(GLOBALS->cat_list);
-	da_payee_destroy(GLOBALS->pay_list);
-	da_account_destroy(GLOBALS->acc_list);
+
+	g_hash_table_destroy(GLOBALS->h_memo);
+
+	da_tag_destroy();
+	da_cat_destroy();
+	da_pay_destroy();	
+	da_acc_destroy();
 
 	/* free our global datas */
 	if( PREFS  )
@@ -889,10 +1084,9 @@ static void homebank_cleanup()
 		g_free(GLOBALS);
 	}
 
-	#ifdef G_OS_WIN32
-		g_free(homebank_pixmaps_dir);
-		g_free(homebank_locale_dir);
-	#endif
+	g_free (pixmaps_dir);	
+	g_free (locale_dir);
+	g_free (help_dir);
 
 }
 
@@ -914,7 +1108,12 @@ GDate *date;
 	PREFS   = g_malloc0(sizeof(struct Preferences));
 	if(!PREFS) return FALSE;
 
+	da_acc_new();
+	da_pay_new();
+	da_cat_new();
+	da_tag_new();
 
+	GLOBALS->h_memo = g_hash_table_new_full(g_str_hash, g_str_equal, (GDestroyNotify)g_free, NULL);
 
 	homebank_register_stock_icons();
 
@@ -939,9 +1138,12 @@ GDate *date;
 	g_date_free(date);
 
 	/* default filename */
-	GLOBALS->filename = g_strdup_printf("%s/untitled.xhb", PREFS->path_wallet);
+	GLOBALS->filename = g_build_filename(PREFS->path_wallet, "untitled.xhb", NULL);
 	GLOBALS->wallet_is_new = TRUE;
 
+	//fix: v4.0
+	GLOBALS->title = g_strdup(_("(Nobody)"));
+
 	//debug
 	#if MYDEBUG == 1
 	/*
@@ -975,25 +1177,23 @@ GtkWidget *frame, *vbox, *image;
 //gchar *ver_string, *markup, *version;
 gchar *pathfilename;
 
-	window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-	gtk_window_set_decorated(GTK_WINDOW(window),FALSE);
+	window = gtk_window_new(GTK_WINDOW_POPUP);	//TOPLEVEL DONT WORK
 	gtk_window_set_type_hint (GTK_WINDOW (window), GDK_WINDOW_TYPE_HINT_SPLASHSCREEN);
-	//gtk_window_set_skip_taskbar_hint (GTK_WINDOW (window), TRUE);
+	gtk_window_set_skip_taskbar_hint (GTK_WINDOW (window), TRUE);
+
 	gtk_window_set_title (GTK_WINDOW (window), "HomeBank");
 	gtk_window_set_position (GTK_WINDOW (window), GTK_WIN_POS_CENTER);
 
-	pathfilename = g_build_filename(homebank_pixmaps_dir, "splash.png", NULL);
+	pathfilename = g_build_filename(homebank_app_get_pixmaps_dir(), "splash.png", NULL);
 	image = gtk_image_new_from_file((const gchar *)pathfilename);
 	g_free(pathfilename);
 
 	frame = gtk_frame_new (NULL);
 	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_OUT);
 	gtk_container_add (GTK_CONTAINER (window), frame);
-	gtk_widget_show (frame);
 
 	vbox = gtk_vbox_new (FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (frame), vbox);
-	gtk_widget_show (vbox);
 
 	/*
 	ver_string = g_strdup_printf(_("Version: HomeBank-%s"), VERSION);
@@ -1005,7 +1205,7 @@ gchar *pathfilename;
 	g_free(ver_string);
 	*/
 
-	gtk_box_pack_start_defaults (GTK_BOX (vbox), image);
+	gtk_box_pack_start (GTK_BOX (vbox), image, FALSE, FALSE, 0);
 	//gtk_box_pack_start (GTK_BOX (vbox), version, FALSE, FALSE, 0);
 
 	return window;
@@ -1028,14 +1228,23 @@ gboolean openlast;
 
 	DB( g_print("\n--------------------------------\nhomebank starting...\n" ) );
 
+	build_package_paths();
+
   /* Initialize i18n support */
 #ifdef ENABLE_NLS
+
+     DB( g_print(" -> enable nls\n" ) );
+
      setlocale (LC_ALL, "");
-     bindtextdomain (GETTEXT_PACKAGE, homebank_locale_dir);
+
+     bindtextdomain (GETTEXT_PACKAGE, locale_dir);
+
      bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
      textdomain (GETTEXT_PACKAGE);
+
 #endif
 
+
 	/* Set up option groups */
 	option_context = g_option_context_new (NULL);
 	
@@ -1087,24 +1296,29 @@ gboolean openlast;
 
 	g_set_application_name (APPLICATION_NAME);
 
+
+
 	splash = homebank_construct_splash();
-	
-	gtk_window_set_auto_startup_notification (FALSE);
-	gtk_widget_show_all (splash);
-	gtk_window_set_auto_startup_notification (TRUE);
-	
-	while (gtk_events_pending ())	/* ensure splash is up */
-		gtk_main_iteration ();
+
+  gtk_window_set_auto_startup_notification (FALSE);
+  gtk_widget_show_all (splash);
+  gtk_window_set_auto_startup_notification (TRUE);
+
+  /* make sure splash is up */
+  while (gtk_events_pending ())
+    gtk_main_iteration ();
+    
 
 	if( homebank_setup() )
 	{
 
-		pathfilename = g_build_filename(homebank_pixmaps_dir, "homebank.svg", NULL);
+		pathfilename = g_build_filename(homebank_app_get_pixmaps_dir(), "homebank.svg", NULL);
 		gtk_window_set_default_icon_from_file(pathfilename, NULL);
 		g_free(pathfilename);
 
 		DB( g_print(" -> creating window\n" ) );
 
+
 		mainwin = (GtkWidget *)create_wallet_window (NULL);
 
 		if(mainwin)
@@ -1116,12 +1330,25 @@ gboolean openlast;
 			gtk_window_move(GTK_WINDOW(mainwin), wg->l, wg->t);
 			gtk_window_resize(GTK_WINDOW(mainwin), wg->w, wg->h);
 
-			//pause
+			//todo: pause on splash
 			//g_usleep( G_USEC_PER_SEC * 1 );
 			gtk_widget_hide(splash);
 
 		    gtk_widget_show_all (mainwin);
 
+#if HB_UNSTABLE == 1
+			homebank_message_dialog(GTK_WINDOW(GLOBALS->mainwindow), GTK_MESSAGE_WARNING,
+				"This is an alpha/beta release of HomeBank",
+				"DO NOT USE it with some important files.\n"
+				"This kind of release is for TESTING ONLY.\n"
+				"It may be buggy, crash, or loose your datas.\n\n"
+				"Please report bugs/questions/suggestions\n"
+				"directly by email to: homebank@free.fr\n\n"
+				"PLEASE DO NOT USE LaunchPad for alpha/beta.\n",
+				NULL
+				);
+#endif
+
 			while (gtk_events_pending ()) /* make sure splash is gone */
 				gtk_main_iteration ();
 
@@ -1130,7 +1357,7 @@ gboolean openlast;
 
 			// load a file ?
 			/* load 1st file specified on commandline */
-			openlast = TRUE;
+			openlast = PREFS->loadlast;
 			if (files != NULL)
 			{
 				if (g_file_test (files[0], G_FILE_TEST_EXISTS) != FALSE)
@@ -1159,7 +1386,9 @@ gboolean openlast;
 			}
 
 			/* update the mainwin display */
-			wallet_update(mainwin, (gpointer)UF_TITLE+UF_SENSITIVE+UF_BALANCE);
+			wallet_update(mainwin, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE+UF_BALANCE));
+
+		DB( g_print(" -> gtk_main()\n" ) );
 
 			gtk_main ();
 		}
