@@ -27,39 +27,6 @@
 extern struct HomeBank *GLOBALS;
 extern struct Preferences *PREFS;
 
-
-//debug
-//extern gboolean minor_active;
-
-//---- start debug
-/*
-static Account debug_accounts[] =
-{
-	{ 1, AF_ADDED, "Compte courant", "bank", "number", 500.15, -150, 12345678, 55553345 },
-	{ 2, AF_ADDED|AF_CHANGED, "Epargne", "bank", "number", 8950, -150, 12345678, 55553345 },
-	{ 3, AF_ADDED|AF_CHANGED, "Livret Z", "bank", "number", 65535, -150, 12345678, 55553345 },
-};
-
-
-
-void debug_populate_acc_list(void)
-{
-struct _Account *entry;
-gint i = 0;
-
-  for (i = 0; i < G_N_ELEMENTS (debug_accounts); i++)
-    {
-	entry = g_malloc(sizeof(struct _Account));
-	//add our entry pointer to the glist
-	memcpy(entry, &debug_accounts[i], sizeof(struct _Account));
-	GLOBALS->acc_list = g_list_append(GLOBALS->acc_list, entry);
-   }
-
-}
-*/
-//---- end debug
-
-
 /*
 ** draw some icons according to the stored data structure
 */
@@ -77,7 +44,7 @@ Account *acc;
 	if( acc != NULL )
 	{
 	
-		switch((gint)user_data)
+		switch(GPOINTER_TO_INT(user_data))
 		{
 			case 1:
 				g_object_set(renderer, "pixbuf", (acc->flags & AF_ADDED) ? GLOBALS->lst_pixbuf[LST_PIXBUF_ADD] : NULL, NULL);
@@ -111,7 +78,7 @@ gchar *groupname;
 
 	if( acc != NULL )
 	{
-		switch((gint)user_data)
+		switch(GPOINTER_TO_INT(user_data))
 		{
 			case 1:
 				g_object_set(renderer, "text", acc->name, NULL);
@@ -139,7 +106,7 @@ gdouble value;
 	//get the account & value
 	gtk_tree_model_get(model, iter,
 		LST_DSPACC_DATAS, &acc,
-		user_data, &value,
+		GPOINTER_TO_INT(user_data), &value,
 		-1);
 
 	if( !(value) )
@@ -192,16 +159,30 @@ GtkCellRenderer    *renderer;
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set(renderer, "xalign", 1.0, NULL);
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, float_cell_data_function, (gpointer)id, NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, float_cell_data_function, GINT_TO_POINTER(id), NULL);
 	//gtk_tree_view_column_set_sizing(column, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
 	gtk_tree_view_column_set_resizable(column, TRUE);
-	gtk_tree_view_column_set_alignment (column, 1.0);
+	gtk_tree_view_column_set_alignment (column, 0.5);
 	gtk_tree_view_column_set_spacing( column, 16 );
 	//gtk_tree_view_column_set_sort_column_id (column, LST_DSPACC_BANK);
 
 	return column;
 }
 
+static gint
+list_account_compare_func (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer userdata)
+{
+gint result = 0;
+Account *entry1, *entry2;
+
+    gtk_tree_model_get(model, a, LST_DSPACC_DATAS, &entry1, -1);
+    gtk_tree_model_get(model, b, LST_DSPACC_DATAS, &entry2, -1);
+
+	result = entry1->pos - entry2->pos;
+
+    return result;
+}
+
 
 /*
  *
@@ -253,11 +234,13 @@ GtkTreeViewColumn  *column;
 
 	/* column 2: Account */
 	column = gtk_tree_view_column_new();
-	gtk_tree_view_column_set_title(column, _("Account"));
+	//gtk_tree_view_column_set_title(column, _("Account"));
 	renderer = gtk_cell_renderer_text_new ();
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, text_cell_data_function, (gpointer)1, NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, text_cell_data_function, GINT_TO_POINTER(1), NULL);
 	gtk_tree_view_column_set_resizable(column, TRUE);
+	gtk_tree_view_column_set_alignment (column, 0.5);
+
 	//gtk_tree_view_column_set_expand(column, TRUE);
 	//gtk_tree_view_column_set_sort_column_id (column, LST_DSPACC_NAME);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
@@ -272,14 +255,16 @@ GtkTreeViewColumn  *column;
   renderer = gtk_cell_renderer_pixbuf_new ();
 	gtk_cell_renderer_set_fixed_size(renderer, GLOBALS->lst_pixbuf_maxwidth, -1);
   gtk_tree_view_column_pack_start(column, renderer, TRUE);
-  gtk_tree_view_column_set_cell_data_func(column, renderer, status_cell_data_function, (gpointer)1, NULL);
+  gtk_tree_view_column_set_cell_data_func(column, renderer, status_cell_data_function, GINT_TO_POINTER(1), NULL);
 
   renderer = gtk_cell_renderer_pixbuf_new ();
 	gtk_cell_renderer_set_fixed_size(renderer, GLOBALS->lst_pixbuf_maxwidth, -1);
   gtk_tree_view_column_pack_start(column, renderer, TRUE);
-  gtk_tree_view_column_set_cell_data_func(column, renderer, status_cell_data_function, (gpointer)2, NULL);
+  gtk_tree_view_column_set_cell_data_func(column, renderer, status_cell_data_function, GINT_TO_POINTER(2), NULL);
 
   /* set this column to a fixed sizing (of 50 pixels) */
+	gtk_tree_view_column_set_alignment (column, 0.5);
+
   //gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN (column), GTK_TREE_VIEW_COLUMN_FIXED);
   //gtk_tree_view_column_set_fixed_width (GTK_TREE_VIEW_COLUMN (column), 50);
   gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
@@ -305,7 +290,9 @@ GtkTreeViewColumn  *column;
 	
 	gtk_tree_selection_set_select_function(gtk_tree_view_get_selection(GTK_TREE_VIEW(view)), list_account_selectionfunc, NULL, NULL);
 	
-
+	//sort etc
+	gtk_tree_sortable_set_default_sort_func(GTK_TREE_SORTABLE(store), list_account_compare_func, NULL, NULL);
+	gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(store), GTK_TREE_SORTABLE_DEFAULT_SORT_COLUMN_ID, GTK_SORT_ASCENDING);
 
 
 	return(view);
