@@ -20,24 +20,23 @@
 #ifndef __MISC__H__
 #define __MISC__H__
 
+gint real_mystrfmon(gchar *outstr, gint outlen, gchar *buf1, struct Currency *cur);
 gint mystrfmon_int(gchar *outstr, gint outlen, gdouble value, gboolean minor);
 gint mystrfmon(gchar *outstr, gint outlen, gdouble value, gboolean minor);
-gint real_mystrfmon(gchar *outstr, gint outlen, gdouble value, struct Currency *cur);
 
-gint hb_strfmon(gchar *outstr, gint outlen, gdouble value, gboolean minor);
-gint hb_strfmonall(gchar *outstr, gint outlen, gdouble value, gboolean minor);
 void hb_label_set_colvalue(GtkLabel *label, gdouble value, gboolean minor);
 
 void get_period_minmax(guint month, guint year, guint32 *mindate, guint32 *maxdate);
 void get_range_minmax(guint32 refdate, gint range, guint32 *mindate, guint32 *maxdate);
 
 void hb_string_strip_crlf(gchar *str);
+gchar* hb_strdup_nobrackets (const gchar *str);
 
 gboolean hb_string_csv_valid(gchar *str, gint nbcolumns, gint *csvtype);
 
 guint32 hb_date_get_julian_parse(gchar *str);
 
-void hex_dump(guchar *ptr, gint length);
+void hex_dump(guchar *ptr, guint length);
 
 
 #endif /* __MISC__H__ */
