@@ -20,6 +20,8 @@
 
 #include "homebank.h"
 
+#include "da_transaction.h"
+#include "hb_transaction.h"
 #include "xml.h"
 
 /****************************************************************************/
@@ -34,9 +36,10 @@
 #endif
 
 /* our global datas */
-struct HomeBank *GLOBALS;
-struct Preferences *PREFS;
+extern struct HomeBank *GLOBALS;
+extern struct Preferences *PREFS;
 
+/*
 typedef enum
 {
   STATE_START,
@@ -48,10 +51,12 @@ typedef enum
   STATE_ACCELERATOR,
   STATE_END
 } ParseState;
+*/
 
 typedef struct _ParseContext ParseContext;
 struct _ParseContext
 {
+/*
   ParseState state;
   ParseState prev_state;
 
@@ -60,6 +65,9 @@ struct _ParseContext
   GNode *current;
 
   guint merge_id;
+*/
+	gdouble	version;
+
 };
 
 static void
@@ -70,10 +78,9 @@ start_element_handler (GMarkupParseContext *context,
 		       gpointer             user_data,
 		       GError             **error)
 {
-//ParseContext *ctx = user_data;
+ParseContext *ctx = user_data;
 //GtkUIManager *self = ctx->self;
 gint i, j;
-gdouble version;
 
 	DB( g_print("** start element: %s\n", element_name) );
 
@@ -81,6 +88,7 @@ gdouble version;
 	switch(element_name[0])
 	{
 		//get file version
+		/*		
 		case 'h':
 		{
 			if(!strcmp (element_name, "homebank"))
@@ -93,24 +101,26 @@ gdouble version;
 			
 			}
 		}
+		*/
 
 		case 'a':
 		{
 			if(!strcmp (element_name, "account"))
 			{
-			Account *entry = da_account_malloc();
+			Account *entry = da_acc_malloc();
 
 				for (i = 0; attribute_names[i] != NULL; i++)
 				{
 					DB( g_print(" att=%s val=%s\n", attribute_names[i], attribute_values[i]) );
 
-					     if(!strcmp (attribute_names[i], "key"     )) { entry->key = atoi(attribute_values[i]); }
+					     if(!strcmp (attribute_names[i], "key"     )) { entry->key   = atoi(attribute_values[i]); }
 					else if(!strcmp (attribute_names[i], "flags"   )) { entry->flags = atoi(attribute_values[i]); }
+					else if(!strcmp (attribute_names[i], "pos"     )) { entry->pos   = atoi(attribute_values[i]); }
 					//todo: for stock account
 					//else if(!strcmp (attribute_names[i], "type"    )) { entry->type = atoi(attribute_values[i]); }
-					else if(!strcmp (attribute_names[i], "name"    )) { if(strcmp(attribute_values[i],"(null)") && attribute_values[i] != "") entry->name = g_strdup(attribute_values[i]); }
-					else if(!strcmp (attribute_names[i], "number"  )) { if(strcmp(attribute_values[i],"(null)") && attribute_values[i] != "") entry->number = g_strdup(attribute_values[i]); }
-					else if(!strcmp (attribute_names[i], "bankname")) { if(strcmp(attribute_values[i],"(null)") && attribute_values[i] != "") entry->bankname = g_strdup(attribute_values[i]); }
+					else if(!strcmp (attribute_names[i], "name"    )) { if(strcmp(attribute_values[i],"(null)") && attribute_values[i] != NULL) entry->name = g_strdup(attribute_values[i]); }
+					else if(!strcmp (attribute_names[i], "number"  )) { if(strcmp(attribute_values[i],"(null)") && attribute_values[i] != NULL) entry->number = g_strdup(attribute_values[i]); }
+					else if(!strcmp (attribute_names[i], "bankname")) { if(strcmp(attribute_values[i],"(null)") && attribute_values[i] != NULL) entry->bankname = g_strdup(attribute_values[i]); }
 					else if(!strcmp (attribute_names[i], "initial" )) { entry->initial = g_ascii_strtod(attribute_values[i], NULL); }
 					else if(!strcmp (attribute_names[i], "minimum" )) { entry->minimum = g_ascii_strtod(attribute_values[i], NULL); }
 					else if(!strcmp (attribute_names[i], "cheque1" )) { entry->cheque1 = atoi(attribute_values[i]); }
@@ -128,9 +138,18 @@ gdouble version;
 				}
 			*/
 
-				//all attribute loaded: append
-				GLOBALS->acc_list = g_list_append(GLOBALS->acc_list, entry);
+				DB( g_print(" version %f\n", ctx->version) );
 
+				//upgrade to v0.2 file
+				// we must change account reference by making a +1 to its index references
+				if( ctx->version == 0.1 )
+				{
+					entry->key++;
+					entry->pos = entry->key;
+				}
+
+				//all attribute loaded: append
+				da_acc_insert(entry);
 			}
 		}
 		break;
@@ -139,7 +158,7 @@ gdouble version;
 		{
 			if(!strcmp (element_name, "pay"))
 			{
-			Payee *entry = da_payee_malloc();
+			Payee *entry = da_pay_malloc();
 
 				for (i = 0; attribute_names[i] != NULL; i++)
 				{
@@ -151,7 +170,7 @@ gdouble version;
 				}
 
 				//all attribute loaded: append
-				GLOBALS->pay_list = g_list_append(GLOBALS->pay_list, entry);
+				da_pay_insert(entry);
 
 			}
 			else if(!strcmp (element_name, "properties"))
@@ -170,12 +189,12 @@ gdouble version;
 		{
 			if(!strcmp (element_name, "cat"))
 			{
-			Category *entry = da_category_malloc();
+			Category *entry = da_cat_malloc();
 			gboolean budget;
 
 				for (i = 0; attribute_names[i] != NULL; i++)
 				{
-					DB( g_print(" att=%s val=%s\n", attribute_names[i], attribute_values[i]) );
+					//DB( g_print(" att=%s val=%s\n", attribute_names[i], attribute_values[i]) );
 
 					     if(!strcmp (attribute_names[i], "key"   )) { entry->key = atoi(attribute_values[i]); }
 					else if(!strcmp (attribute_names[i], "parent")) { entry->parent = atoi(attribute_values[i]); }
@@ -199,12 +218,33 @@ gdouble version;
 				}
 
 				//all attribute loaded: append
-				GLOBALS->cat_list = g_list_append(GLOBALS->cat_list, entry);
+				da_cat_insert( entry);
 
 			}
 		}
 		break;
 
+		case 't':
+		{
+			if(!strcmp (element_name, "tags"))
+			{
+			Tag *entry = da_tag_malloc();
+
+				for (i = 0; attribute_names[i] != NULL; i++)
+				{
+					DB( g_print(" att=%s val=%s\n", attribute_names[i], attribute_values[i]) );
+
+					     if(!strcmp (attribute_names[i], "key"  )) { entry->key = atoi(attribute_values[i]); }
+					//else if(!strcmp (attribute_names[i], "flags")) { entry->flags = atoi(attribute_values[i]); }
+					else if(!strcmp (attribute_names[i], "name" )) { entry->name = g_strdup(attribute_values[i]); }
+				}
+
+				//all attribute loaded: append
+				da_tag_insert(entry);
+
+			}
+		}
+
 		case 'f':
 		{
 			if(!strcmp (element_name, "fav"))
@@ -213,7 +253,7 @@ gdouble version;
 
 				for (i = 0; attribute_names[i] != NULL; i++)
 				{
-					DB( g_print(" att=%s val=%s\n", attribute_names[i], attribute_values[i]) );
+					//DB( g_print(" att=%s val=%s\n", attribute_names[i], attribute_values[i]) );
 
 					     if(!strcmp (attribute_names[i], "amount"     )) { entry->amount = g_ascii_strtod(attribute_values[i], NULL); }
 					else if(!strcmp (attribute_names[i], "account"    )) { entry->account = atoi(attribute_values[i]); }
@@ -222,7 +262,7 @@ gdouble version;
 					else if(!strcmp (attribute_names[i], "flags"      )) { entry->flags = atoi(attribute_values[i]); }
 					else if(!strcmp (attribute_names[i], "payee"      )) { entry->payee = atoi(attribute_values[i]); }
 					else if(!strcmp (attribute_names[i], "category"   )) { entry->category = atoi(attribute_values[i]); }
-					else if(!strcmp (attribute_names[i], "wording"    )) { if(strcmp(attribute_values[i],"(null)") && attribute_values[i] != "") entry->wording = g_strdup(attribute_values[i]); }
+					else if(!strcmp (attribute_names[i], "wording"    )) { if(strcmp(attribute_values[i],"(null)") && attribute_values[i] != NULL) entry->wording = g_strdup(attribute_values[i]); }
 					else if(!strcmp (attribute_names[i], "nextdate"   )) { entry->nextdate = atoi(attribute_values[i]); }
 					else if(!strcmp (attribute_names[i], "every"      )) { entry->every = atoi(attribute_values[i]); }
 					else if(!strcmp (attribute_names[i], "unit"       )) { entry->unit = atoi(attribute_values[i]); }
@@ -245,7 +285,7 @@ gdouble version;
 
 				for (i = 0; attribute_names[i] != NULL; i++)
 				{
-					DB( g_print(" att=%s val=%s\n", attribute_names[i], attribute_values[i]) );
+					//DB( g_print(" att=%s val=%s\n", attribute_names[i], attribute_values[i]) );
 
 					     if(!strcmp (attribute_names[i], "date"       )) { entry->date = atoi(attribute_values[i]); }
 					else if(!strcmp (attribute_names[i], "amount"     )) { entry->amount = g_ascii_strtod(attribute_values[i], NULL); }
@@ -255,14 +295,23 @@ gdouble version;
 					else if(!strcmp (attribute_names[i], "flags"      )) { entry->flags = atoi(attribute_values[i]); }
 					else if(!strcmp (attribute_names[i], "payee"      )) { entry->payee = atoi(attribute_values[i]); }
 					else if(!strcmp (attribute_names[i], "category"   )) { entry->category = atoi(attribute_values[i]); }
-					else if(!strcmp (attribute_names[i], "wording"    )) { if(strcmp(attribute_values[i],"(null)") && attribute_values[i] != "") entry->wording = g_strdup(attribute_values[i]); }
-					else if(!strcmp (attribute_names[i], "info"       )) { if(strcmp(attribute_values[i],"(null)") && attribute_values[i] != "") entry->info = g_strdup(attribute_values[i]); }
-
+					else if(!strcmp (attribute_names[i], "wording"    )) { if(strcmp(attribute_values[i],"(null)") && attribute_values[i] != NULL) entry->wording = g_strdup(attribute_values[i]); }
+					else if(!strcmp (attribute_names[i], "info"       )) { if(strcmp(attribute_values[i],"(null)") && attribute_values[i] != NULL) entry->info = g_strdup(attribute_values[i]); }
+					else if(!strcmp (attribute_names[i], "tags"       ))
+					{
+						if(strcmp(attribute_values[i],"(null)") && attribute_values[i] != NULL)
+						{
+							transaction_set_tags(entry, attribute_values[i]);
+						}
+					}
 				}
 
+				//bugfix 303886
+				if(entry->category < 0)
+					entry->category = 0;
+				
 				//all attribute loaded: append
-				GLOBALS->ope_list = g_list_append(GLOBALS->ope_list, entry);
-
+				da_operation_append(entry);				
 			}
 		}
 		break;
@@ -326,11 +375,17 @@ gboolean rc;
 		if( v_buffer == NULL )
 			return XML_FILE_ERROR;
 
+		DB( g_print("id line: %s", v_buffer) );
+
 		version = g_ascii_strtod(v_buffer+13, NULL);	/* a little hacky, but works ! */
+		if( version == 0.0 )
+			version = 0.1;
+
+		ctx.version = version;
 
 		if( version > FILE_VERSION )
 		{
-			DB( g_print("failed: version %.1f is not supported (max is %.1f\n", version, FILE_VERSION) );
+			DB( g_print("failed: version %f is not supported (max is %f)\n", version, FILE_VERSION) );
 			return XML_VERSION_ERROR;
 		}
 		else
@@ -358,6 +413,74 @@ gboolean rc;
 
 
 			g_free (buffer);
+
+			//upgrade to v0.2 file
+			// we must change account reference by making a +1 to its index references
+			if( version == 0.1 )
+			{
+			GList *list;
+
+				list = g_list_first(GLOBALS->ope_list);
+				while (list != NULL)
+				{
+				Operation *entry = list->data;
+					entry->account++;
+					entry->dst_account++;
+					list = g_list_next(list);
+				}
+
+				list = g_list_first(GLOBALS->arc_list);
+				while (list != NULL)
+				{
+				Archive *entry = list->data;
+					entry->account++;
+					entry->dst_account++;
+					list = g_list_next(list);
+				}
+
+			}
+
+			//upgrade to v0.3 file
+			// we must assume categories exists : bugs 303886, 303738
+			if( version == 0.2 )
+			{
+			Category *cat;
+			GList *list;
+
+				list = g_list_first(GLOBALS->ope_list);
+				while (list != NULL)
+				{
+				Operation *entry = list->data;
+
+					cat = da_cat_get(entry->category);
+					if(cat == NULL)
+					{
+						DB( g_print(" !! fixing cat for ope: %d is unknow\n", entry->category) );
+						entry->category = 0;
+					}
+
+					list = g_list_next(list);
+				}
+
+				list = g_list_first(GLOBALS->arc_list);
+				while (list != NULL)
+				{
+				Archive *entry = list->data;
+
+					cat = da_cat_get(entry->category);
+					if(cat == NULL)
+					{
+						DB( g_print(" !! fixing cat for arc: %d is unknow\n", entry->category) );
+						entry->category = 0;
+					}
+
+					list = g_list_next(list);
+				}
+
+			}
+
+
+
 		}
 	}
 
@@ -365,22 +488,26 @@ gboolean rc;
 }
 
 
+/* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
 
 /*
 ** XML properties save
 */
-static void homebank_prop_save_xml(FILE *fp)
+static void homebank_prop_save_xml(GIOChannel *io)
 {
 gchar *tmpstr;
+gchar *title;
+
+	title = GLOBALS->title == NULL ? "" : GLOBALS->title;
 
 	tmpstr = g_markup_printf_escaped("<properties title=\"%s\" car_category=\"%d\" auto_nbdays=\"%d\"/>\n",
-		GLOBALS->title,
+		title,
 		GLOBALS->car_category,
 		GLOBALS->auto_nbdays
 	);
 
-	fprintf(fp, tmpstr);
+	g_io_channel_write_chars(io, tmpstr, -1, NULL, NULL);
 	g_free(tmpstr);
 
 }
@@ -389,7 +516,7 @@ gchar *tmpstr;
 /*
 ** XML account save
 */
-static void homebank_acc_save_xml(FILE *fp)
+static void homebank_acc_save_xml(GIOChannel *io)
 {
 GList *list;
 char buf1[G_ASCII_DTOSTR_BUF_SIZE];
@@ -400,7 +527,7 @@ gchar *tmpstr;
 	//char buf[G_ASCII_DTOSTR_BUF_SIZE];
 	//fprintf (out, "value=%s\n", g_ascii_dtostr (buf, sizeof (buf), value));
 
-	list = g_list_first(GLOBALS->acc_list);
+	list = g_hash_table_get_values(GLOBALS->h_acc);
 	while (list != NULL)
 	{
 	Account *item = list->data;
@@ -409,11 +536,12 @@ gchar *tmpstr;
 
 		//todo: for stock account
 		//tmpstr = g_markup_printf_escaped("<account key=\"%d\" flags=\"%d\" type=\"%d\" name=\"%s\"\n"
-		tmpstr = g_markup_printf_escaped("<account key=\"%d\" flags=\"%d\" name=\"%s\"\n"
-			" number=\"%s\" bankname=\"%s\" initial=\"%s\" minimum=\"%s\"\n"
+		tmpstr = g_markup_printf_escaped("<account key=\"%d\" flags=\"%d\" pos=\"%d\" name=\"%s\""
+			" number=\"%s\" bankname=\"%s\" initial=\"%s\" minimum=\"%s\""
 			" cheque1=\"%d\" cheque2=\"%d\"/>\n",
 			item->key,
 			item->flags,
+			item->pos,
 			//todo: for stock account
 			//item->type,
 			item->name == NULL ? "" : item->name,
@@ -425,22 +553,23 @@ gchar *tmpstr;
 			item->cheque2
 		);
 
-		fprintf(fp, tmpstr);
+		g_io_channel_write_chars(io, tmpstr, -1, NULL, NULL);
 		g_free(tmpstr);
 	
 		list = g_list_next(list);
 	}
+	g_list_free(list);
 }
 
 /*
 ** XML payee save
 */
-static void homebank_pay_save_xml(FILE *fp)
+static void homebank_pay_save_xml(GIOChannel *io)
 {
 GList *list;
 gchar *tmpstr;
 
-	list = g_list_first(GLOBALS->pay_list);
+	list = g_hash_table_get_values(GLOBALS->h_pay);
 	while (list != NULL)
 	{
 	Payee *item = list->data;
@@ -452,25 +581,26 @@ gchar *tmpstr;
 				item->name
 			);
 			
-			fprintf(fp, tmpstr);
+			g_io_channel_write_chars(io, tmpstr, -1, NULL, NULL);
 			g_free(tmpstr);
 
 		}
 		list = g_list_next(list);
 	}
+	g_list_free(list);
 }
 
 /*
 ** XML category save
 */
-static void homebank_cat_save_xml(FILE *fp)
+static void homebank_cat_save_xml(GIOChannel *io)
 {
 GList *list;
 guint i;
 char buf[G_ASCII_DTOSTR_BUF_SIZE];
 gchar *tmpstr;
 
-	list = g_list_first(GLOBALS->cat_list);
+	list = g_hash_table_get_values(GLOBALS->h_cat);
 	while (list != NULL)
 	{
 	Category *item = list->data;
@@ -484,26 +614,59 @@ gchar *tmpstr;
 				item->name
 			);
 
-			fprintf(fp, tmpstr);
+			g_io_channel_write_chars(io, tmpstr, -1, NULL, NULL);
 			g_free(tmpstr);
 
 			for(i=0;i<=12;i++)
 			{
 				if(item->budget[i] != 0)
-					fprintf(fp, " b%d=\"%s\"", i, g_ascii_dtostr (buf, sizeof (buf), item->budget[i]));
+				{
+					tmpstr = g_strdup_printf(" b%d=\"%s\"", i, g_ascii_dtostr (buf, sizeof (buf), item->budget[i]));
+					g_io_channel_write_chars(io, tmpstr, -1, NULL, NULL);
+					g_free(tmpstr);
+				}
 			}
 
-			fprintf(fp, "/>\n");
+			g_io_channel_write_chars(io, "/>\n", -1, NULL, NULL);
 
 		}
 		list = g_list_next(list);
 	}
 }
 
+/*
+** XML tag save
+*/
+static void homebank_tag_save_xml(GIOChannel *io)
+{
+GList *list;
+gchar *tmpstr;
+
+	list = g_hash_table_get_values(GLOBALS->h_tag);
+	while (list != NULL)
+	{
+	Tag *item = list->data;
+
+		if(item->key != 0)
+		{
+			tmpstr = g_markup_printf_escaped("<tag key=\"%d\" name=\"%s\"/>\n",
+				item->key,
+				item->name
+			);
+			
+			g_io_channel_write_chars(io, tmpstr, -1, NULL, NULL);
+			g_free(tmpstr);
+
+		}
+		list = g_list_next(list);
+	}
+	g_list_free(list);
+}
+
 /*
 ** XML archive save
 */
-static void homebank_arc_save_xml(FILE *fp)
+static void homebank_arc_save_xml(GIOChannel *io)
 {
 GList *list;
 char buf[G_ASCII_DTOSTR_BUF_SIZE];
@@ -514,18 +677,24 @@ gchar *tmpstr;
 	{
 	Archive *item = list->data;
 
-		fprintf(fp, "<fav amount=\"%s\" account=\"%d\" dst_account=\"%d\"\n",
+		tmpstr = g_strdup_printf("<fav amount=\"%s\" account=\"%d\" dst_account=\"%d\"",
 			g_ascii_dtostr (buf, sizeof (buf), item->amount),
 			item->account,
 			item->dst_account
 		);
+		g_io_channel_write_chars(io, tmpstr, -1, NULL, NULL);
+		g_free(tmpstr);
 
-		fprintf(fp, " paymode=\"%d\" flags=\"%d\" payee=\"%d\" category=\"%d\"\n",
+
+		tmpstr = g_strdup_printf(" paymode=\"%d\" flags=\"%d\" payee=\"%d\" category=\"%d\"",
 			item->paymode,
 			item->flags,
 			item->payee,
 			item->category
 		);
+		g_io_channel_write_chars(io, tmpstr, -1, NULL, NULL);
+		g_free(tmpstr);
+
 
 		tmpstr = g_markup_printf_escaped(" wording=\"%s\" nextdate=\"%d\" every=\"%d\" unit=\"%d\" limit=\"%d\"/>\n",
 			item->wording == NULL ? "" : item->wording,
@@ -535,7 +704,7 @@ gchar *tmpstr;
 			item->limit
 		);
 
-		fprintf(fp, tmpstr);
+		g_io_channel_write_chars(io, tmpstr, -1, NULL, NULL);
 		g_free(tmpstr);
 
 		list = g_list_next(list);
@@ -545,11 +714,12 @@ gchar *tmpstr;
 /*
 ** XML operation save
 */
-static void homebank_ope_save_xml(FILE *fp)
+static void homebank_ope_save_xml(GIOChannel *io)
 {
 GList *list;
 char buf[G_ASCII_DTOSTR_BUF_SIZE];
 gchar *tmpstr;
+gchar *tagstr;
 
 	list = g_list_first(GLOBALS->ope_list);
 	while (list != NULL)
@@ -558,8 +728,11 @@ gchar *tmpstr;
 
 		item->flags &= (OF_VALID|OF_INCOME|OF_REMIND);
 
+		tagstr = transaction_get_tagstring(item);
+
 		tmpstr = g_markup_printf_escaped(
-			"<ope date=\"%d\" amount=\"%s\" account=\"%d\" dst_account=\"%d\" paymode=\"%d\" flags=\"%d\" payee=\"%d\" category=\"%d\" wording=\"%s\" info=\"%s\"/>\n",
+			"<ope date=\"%d\" amount=\"%s\" account=\"%d\" dst_account=\"%d\" paymode=\"%d\" flags=\"%d\" "
+			"payee=\"%d\" category=\"%d\" wording=\"%s\" info=\"%s\" tags=\"%s\"/>\n",
 			item->date,
 			g_ascii_dtostr (buf, sizeof (buf), item->amount),
 			item->account,
@@ -569,10 +742,13 @@ gchar *tmpstr;
 			item->payee,
 			item->category,
 			item->wording == NULL ? "" : item->wording,
-			item->info == NULL ? "" : item->info
+			item->info == NULL ? "" : item->info,
+			item->tags == NULL ? "" : tagstr			
 		);
 
-		fprintf(fp, tmpstr);
+		g_free(tagstr);
+
+		g_io_channel_write_chars(io, tmpstr, -1, NULL, NULL);
 		g_free(tmpstr);
 
 		list = g_list_next(list);
@@ -584,25 +760,33 @@ gchar *tmpstr;
 */
 void homebank_save_xml(gchar *filename)
 {
-FILE *fp;
+GIOChannel *io;
+char buf1[G_ASCII_DTOSTR_BUF_SIZE];
+gchar *outstr;
 
-	if ((fp = fopen(filename, "w")) == NULL)
+	io = g_io_channel_new_file(filename, "w", NULL);
+	if(io == NULL)
 	{
 		g_message("file error on: %s", filename);
 	}
 	else
 	{
-		fputs("<?xml version=\"1.0\"?>\n", fp);
-		fprintf(fp, "<homebank v=\"%.1f\">\n", FILE_VERSION);
+		g_io_channel_write_chars(io, "<?xml version=\"1.0\"?>\n", -1, NULL, NULL);
+		
+		outstr = g_strdup_printf("<homebank v=\"%s\">\n", g_ascii_dtostr (buf1, sizeof (buf1), FILE_VERSION));
+		g_io_channel_write_chars(io, outstr, -1, NULL, NULL);
+		g_free(outstr);
 
-		homebank_prop_save_xml(fp);
-		homebank_acc_save_xml(fp);
-		homebank_pay_save_xml(fp);
-		homebank_cat_save_xml(fp);
-		homebank_arc_save_xml(fp);
-		homebank_ope_save_xml(fp);
+		homebank_prop_save_xml(io);
+		homebank_acc_save_xml(io);
+		homebank_pay_save_xml(io);
+		homebank_cat_save_xml(io);
+		homebank_tag_save_xml(io);
+		homebank_arc_save_xml(io);
+		homebank_ope_save_xml(io);
 
-		fputs("</homebank>\n", fp);
-		fclose(fp);
+		g_io_channel_write_chars(io, "</homebank>\n", -1, NULL, NULL);
+
+		g_io_channel_unref (io);
 	}
 }
